pub enum Message {
Show 16 variants
Offer(OfferDlc),
Accept(AcceptDlc),
Sign(SignDlc),
OfferChannel(OfferChannel),
AcceptChannel(AcceptChannel),
SignChannel(SignChannel),
SettleOffer(SettleOffer),
SettleAccept(SettleAccept),
SettleConfirm(SettleConfirm),
SettleFinalize(SettleFinalize),
RenewOffer(RenewOffer),
RenewAccept(RenewAccept),
RenewConfirm(RenewConfirm),
RenewFinalize(RenewFinalize),
CollaborativeCloseOffer(CollaborativeCloseOffer),
Reject(Reject),
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the type identifying the message payload.
Writes self out to the given Writer
Writes self out to a Vec
Gets the length of this object after it has been serialized. This can be overridden to
optimize cases where we prepend an object with its length.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.