pub enum Error {
InvalidState(String),
InvalidParameter(String),
}Expand description
An error that occured while processing message segmentation related messages.
Variants
InvalidState(String)
The reader is in a state that is invalid.
InvalidParameter(String)
A parameter received by the reader was not in accordance with its state.